@@ -1,4 +1,3 @@
-#include <wx/defs.h>
 #include <libfilezilla/libfilezilla.hpp>
 #ifdef FZ_WINDOWS
   #include <libfilezilla/private/windows.hpp>
@@ -17,6 +16,8 @@
 
 #include <algorithm>
 
+#include <string.h>
+
 enum handshake_state
 {
 	http_wait,
@@ -59,7 +60,7 @@ std::wstring CProxySocket::Name(ProxyType t)
 	case SOCKS5:
 		return L"SOCKS5";
 	default:
-		return _("unknown").ToStdWstring();
+		return _("unknown");
 	}
 }
 
@@ -99,10 +100,11 @@ int CProxySocket::Handshake(CProxySocket::ProxyType type, std::wstring const& ho
 		std::string host_raw = fz::to_utf8(host);
 		m_pSendBuffer = new char[70 + host_raw.size() * 2 + 2*5 + auth.size() + 23];
 
-		m_sendBufferLen = sprintf(m_pSendBuffer, "CONNECT %s:%u HTTP/1.1\r\nHost: %s:%u\r\n%sUser-Agent: FileZilla\r\n\r\n",
+		m_sendBufferLen = sprintf(m_pSendBuffer, "CONNECT %s:%u HTTP/1.1\r\nHost: %s:%u\r\n%sUser-Agent: %s\r\n\r\n",
 			host_raw.c_str(), port,
 			host_raw.c_str(), port,
-			auth.c_str());
+			auth.c_str(),
+			fz::replaced_substrings(PACKAGE_STRING, " ", "/").c_str());
 
 		m_pRecvBuffer = new char[4096];
 		m_recvBufferLen = 4096;
@@ -280,7 +282,7 @@ void CProxySocket::OnReceive()
 				}
 				if (m_pSendBuffer) {
 					m_proxyState = noconn;
-					m_pOwner->LogMessage(MessageType::Debug_Warning, _T("Incoming data before request fully sent"));
+					m_pOwner->LogMessage(MessageType::Debug_Warning, L"Incoming data before request fully sent");
 					m_pEvtHandler->send_event<CSocketEvent>(this, SocketEventType::close, ECONNABORTED);
 					return;
 				}
@@ -292,7 +294,7 @@ void CProxySocket::OnReceive()
 					if (!end) {
 						if (m_recvBufferPos + read + 1 == m_recvBufferLen) {
 							m_proxyState = noconn;
-							m_pOwner->LogMessage(MessageType::Debug_Warning, _T("Incoming header too large"));
+							m_pOwner->LogMessage(MessageType::Debug_Warning, L"Incoming header too large");
 							m_pEvtHandler->send_event<CSocketEvent>(this, SocketEventType::close, ENOMEM);
 							return;
 						}
@@ -304,7 +306,7 @@ void CProxySocket::OnReceive()
 				else {
 					if (read != do_read) {
 						m_proxyState = noconn;
-						m_pOwner->LogMessage(MessageType::Debug_Warning, _T("Could not read what got peeked"));
+						m_pOwner->LogMessage(MessageType::Debug_Warning, "Could not read what got peeked");
 						m_pEvtHandler->send_event<CSocketEvent>(this, SocketEventType::close, ECONNABORTED);
 						return;
 					}
@@ -358,7 +360,7 @@ void CProxySocket::OnReceive()
 			m_recvBufferPos = 0;
 
 			if (m_pRecvBuffer[1] != 0x5A) {
-				wxString error;
+				std::wstring error;
 				switch (m_pRecvBuffer[1]) {
 					case 0x5B:
 						error = _("Request rejected or failed");
@@ -370,7 +372,7 @@ void CProxySocket::OnReceive()
 						error = _("Request failed - client's identd could not confirm the user ID string");
 						break;
 					default:
-						error.Printf(_("Unassigned error code %d"), (int)(unsigned char) m_pRecvBuffer[1]);
+						error = fz::sprintf(_("Unassigned error code %d"), (int)(unsigned char)m_pRecvBuffer[1]);
 						break;
 				}
 				m_pOwner->LogMessage(MessageType::Error, _("Proxy request failed: %s"), error);
@@ -468,7 +470,7 @@ void CProxySocket::OnReceive()
 				break;
 			case socks5_request:
 				if (m_pRecvBuffer[1]) {
-					wxString errorMsg;
+					std::wstring errorMsg;
 					switch (m_pRecvBuffer[1])
 					{
 					case 1:
@@ -496,7 +498,7 @@ void CProxySocket::OnReceive()
 						errorMsg = _("Address type not supported");
 						break;
 					default:
-						errorMsg.Printf(_("Unassigned error code %d"), (int)(unsigned char)m_pRecvBuffer[1]);
+						errorMsg = fz::sprintf(_("Unassigned error code %d"), (int)(unsigned char)m_pRecvBuffer[1]);
 						break;
 					}
 
@@ -539,7 +541,7 @@ void CProxySocket::OnReceive()
 					return;
 				}
 			default:
-				wxFAIL;
+				assert(false);
 				break;
 			}
 
@@ -547,13 +549,15 @@ void CProxySocket::OnReceive()
 			{
 			case socks5_auth:
 				{
-					m_sendBufferLen = m_user.size() + m_pass.size() + 3;
+					auto ulen = static_cast<unsigned char>(std::min(m_user.size(), size_t(255)));
+					auto plen = static_cast<unsigned char>(std::min(m_pass.size(), size_t(255)));
+					m_sendBufferLen = ulen + plen + 3;
 					m_pSendBuffer = new char[m_sendBufferLen];
 					m_pSendBuffer[0] = 1;
-					m_pSendBuffer[1] = m_user.size();
-					memcpy(m_pSendBuffer + 2, m_user.c_str(), m_user.size());
-					m_pSendBuffer[m_user.size() + 2] = m_pass.size();
-					memcpy(m_pSendBuffer + m_user.size() + 3, m_pass.c_str(), m_pass.size());
+					m_pSendBuffer[1] = ulen;
+					memcpy(m_pSendBuffer + 2, m_user.c_str(), ulen);
+					m_pSendBuffer[ulen + 2] = plen;
+					memcpy(m_pSendBuffer + ulen + 3, m_pass.c_str(), plen);
 					m_recvBufferLen = 2;
 				}
 				break;
@@ -597,9 +601,11 @@ void CProxySocket::OnReceive()
 					}
 					else {
 						m_pSendBuffer[3] = 3; // Domain name
-						m_pSendBuffer[4] = host.size();
-						memcpy(m_pSendBuffer + 5, host.c_str(), host.size());
-						addrlen = host.size() + 1;
+
+						auto hlen = static_cast<unsigned char>(std::min(host.size(), size_t(255)));
+						m_pSendBuffer[4] = hlen;
+						memcpy(m_pSendBuffer + 5, host.c_str(), hlen);
+						addrlen = hlen + 1;
 					}
 
 					m_pSendBuffer[addrlen + 4] = (m_port >> 8) & 0xFF; // Port in network order
@@ -614,7 +620,7 @@ void CProxySocket::OnReceive()
 				// Nothing to send, we simply need to wait for more data
 				break;
 			default:
-				wxFAIL;
+				assert(false);
 				break;
 			}
 			if (m_pSendBuffer && m_can_write)
@@ -623,7 +629,7 @@ void CProxySocket::OnReceive()
 		break;
 	default:
 		m_proxyState = noconn;
-		m_pOwner->LogMessage(MessageType::Debug_Warning, _T("Unhandled handshake state %d"), m_handshakeState);
+		m_pOwner->LogMessage(MessageType::Debug_Warning, L"Unhandled handshake state %d", m_handshakeState);
 		m_pEvtHandler->send_event<CSocketEvent>(this, SocketEventType::close, ECONNABORTED);
 		return;
 	}
