@@ -175,6 +175,18 @@ void CContextManager::NotifyGlobalHandlers(t_statechange_notifications notificat
 	}
 }
 
+void CContextManager::ProcessDirectoryListing(CServer const& server, std::shared_ptr<CDirectoryListing> const& listing, CState const* exempt)
+{
+	for (auto state : m_contexts) {
+		if (state == exempt) {
+			continue;
+		}
+		if (state->GetServer() && *state->GetServer() == server) {
+			state->SetRemoteDir(listing, true);
+		}
+	}
+}
+
 CState::CState(CMainFrame &mainFrame)
 	: m_mainFrame(mainFrame)
 {
@@ -245,14 +257,16 @@ bool CState::SetLocalDir(CLocalPath const& dir, std::wstring *error, bool rememb
 			wxString msg = wxString::Format(_("The local directory '%s' is not below the synchronization root (%s).\nDisable synchronized browsing and continue changing the local directory?"),
 					dir.GetPath(),
 					m_sync_browse.local_root.GetPath());
-			if (wxMessageBoxEx(msg, _("Synchronized browsing"), wxICON_QUESTION | wxYES_NO) != wxYES)
+			if (wxMessageBoxEx(msg, _("Synchronized browsing"), wxICON_QUESTION | wxYES_NO) != wxYES) {
 				return false;
+			}
 			SetSyncBrowse(false);
 		}
 		else if (!IsRemoteIdle(true)) {
 			wxString msg(_("A remote operation is in progress and synchronized browsing is enabled.\nDisable synchronized browsing and continue changing the local directory?"));
-			if (wxMessageBoxEx(msg, _("Synchronized browsing"), wxICON_QUESTION | wxYES_NO) != wxYES)
+			if (wxMessageBoxEx(msg, _("Synchronized browsing"), wxICON_QUESTION | wxYES_NO) != wxYES) {
 				return false;
+			}
 			SetSyncBrowse(false);
 		}
 		else {
@@ -285,8 +299,9 @@ bool CState::SetLocalDir(CLocalPath const& dir, std::wstring *error, bool rememb
 #endif
 			m_previouslyVisitedLocalSubdir = m_localDir.GetLastSegment();
 	}
-	else
+	else {
 		m_previouslyVisitedLocalSubdir = _T("");
+	}
 
 
 	m_localDir = dir;
@@ -481,7 +496,7 @@ void CState::SetSite(Site const& site, CServerPath const& path)
 		}
 		m_last_site = site;
 	}
-	
+
 	m_site = site;
 
 	UpdateTitle();
@@ -580,7 +595,7 @@ void CState::RegisterHandler(CStateEventHandler* pHandler, t_statechange_notific
 	wxASSERT(notification != STATECHANGE_MAX && notification != STATECHANGE_NONE);
 	wxASSERT(pHandler != insertBefore);
 
-	
+
 	auto &handlers = m_handlers[notification];
 	auto insertionPoint = handlers.end();
 
@@ -973,6 +988,9 @@ void CState::ListingFailed(int)
 				SetLocalDir(local);
 			}
 		}
+		else {
+			m_changeDirFlags.syncbrowse = false;
+		}
 	}
 }
 
