@@ -475,12 +475,12 @@ int sftp_get_file(char *fname, char *outfname, int recurse, int restart)
 	    
 	offset = get_file_posn(file);
 	uint64_decimal(offset, decbuf);
-	fzprintf(sftpStatus, "reget: restarting at file position %s", decbuf);
+	fzprintf(sftpInfo, "reget: restarting at file position %s", decbuf);
     } else {
 	offset = uint64_make(0, 0);
     }
 
-    fzprintf(sftpStatus, "remote:%s => local:%s", fname, outfname);
+    fzprintf(sftpInfo, "remote:%s => local:%s", fname, outfname);
 
     fz_timer_init(&timer);
     winterval = 0;
@@ -561,7 +561,7 @@ int sftp_put_file(char *fname, char *outfname, int recurse, int restart)
     struct sftp_request *req;
     uint64 offset;
     RFile *file;
-    int ret, err, eof;
+    int err = 0, eof;
     struct fxp_attrs attrs;
     long permissions;
 
@@ -714,6 +714,7 @@ int sftp_put_file(char *fname, char *outfname, int recurse, int restart)
     if (restart) {
 	char decbuf[30];
 	struct fxp_attrs attrs;
+        int ret;
 
 	req = fxp_fstat_send(fh);
         pktin = sftp_wait_for_reply(req);
@@ -721,33 +722,33 @@ int sftp_put_file(char *fname, char *outfname, int recurse, int restart)
 
 	if (!ret) {
 	    fzprintf(sftpError, "read size of %s: %s", outfname, fxp_error());
-	    goto cleanup;
+	    err = 1;
+            goto cleanup;
 	}
 	if (!(attrs.flags & SSH_FILEXFER_ATTR_SIZE)) {
 	    fzprintf(sftpError, "read size of %s: size was not given", outfname);
-	    ret = 0;
-	    goto cleanup;
+	    err = 1;
+            goto cleanup;
 	}
 	offset = attrs.size;
 	uint64_decimal(offset, decbuf);
-	fzprintf(sftpStatus, "reput: restarting at file position %s", decbuf);
+	fzprintf(sftpInfo, "reput: restarting at file position %s", decbuf);
 	if (seek_file((WFile *)file, offset, FROM_START) != 0)
 	    seek_file((WFile *)file, uint64_make(0,0), FROM_END);    /* *shrug* */
     } else {
 	offset = uint64_make(0, 0);
     }
 
-    fzprintf(sftpStatus, "local:%s => remote:%s\n", fname, outfname);
+    fzprintf(sftpInfo, "local:%s => remote:%s\n", fname, outfname);
 
     /*
      * FIXME: we can use FXP_FSTAT here to get the file size, and
      * thus put up a progress bar.
      */
-    ret = 1;
     xfer = xfer_upload_init(fh, offset);
-    err = eof = 0;
+    eof = 0;
     while ((!err && !eof) || !xfer_done(xfer)) {
-        char buffer[4096*4];
+	char buffer[4096*4];
 	int len, ret;
 
 	while (xfer_upload_ready(xfer) && !err && !eof) {
@@ -771,24 +772,28 @@ int sftp_put_file(char *fname, char *outfname, int recurse, int restart)
                 if (ret == INT_MIN)        /* pktin not even freed */
                     sfree(pktin);
                 if (!err) {
-		    fzprintf(sftpError, "error while writing: %s", fxp_error());
-		    err = 1;
-		}
-		ret = 0;
+                    fzprintf(sftpError, "error while writing: %s", fxp_error());
+                    err = 1;
+                }
 	    }
 	}
     }
 
     xfer_cleanup(xfer);
 
-cleanup:
+  cleanup:
     req = fxp_close_send(fh);
     pktin = sftp_wait_for_reply(req);
-    fxp_close_recv(pktin, req);
+    if (!fxp_close_recv(pktin, req)) {
+	if (!err) {
+	    fzprintf(sftpError, "error while writing: %s", fxp_error());
+	    err = 1;
+	}
+    }
 
     close_rfile(file);
 
-    return ret;
+    return (err == 0) ? 1 : 0;
 }
 
 /* ----------------------------------------------------------------------
@@ -1240,7 +1245,7 @@ int sftp_cmd_ls(struct sftp_command *cmd)
 	    if (ournames[i]->attrs.flags & SSH_FILEXFER_ATTR_ACMODTIME) {
 		mtime = ournames[i]->attrs.mtime;
 	    }
-	    fzprintf_raw_untrusted(sftpListentry, ournames[i]->longname);
+	    fzprintf_raw_untrusted(sftpListentry, "%s", ournames[i]->longname);
 	    fzprintf_raw_untrusted(sftpUnknown, "%lu", mtime);
 	    fzprintf_raw_untrusted(sftpUnknown, "%s", ournames[i]->filename);
 	    fxp_free_name(ournames[i]);
@@ -1780,7 +1785,8 @@ int sftp_cmd_mv(struct sftp_command *cmd)
      * argument which is a wildcard, we _require_ that the
      * destination is a directory.
      */
-    ctx->dest_is_dir = check_is_dir(ctx->dstfname);
+    /*FZ: Force dest_is_dir to FALSE. See #11047 */
+    ctx->dest_is_dir = FALSE; /*check_is_dir(ctx->dstfname);*/
     if ((cmd->nwords > 3 || is_wildcard(cmd->words[1])) && !ctx->dest_is_dir) {
 	fzprintf(sftpError, "mv: multiple or wildcard arguments require the destination"
 	       " to be a directory");
@@ -3007,6 +3013,8 @@ static void usage(void)
     printf("  -hostkey aa:bb:cc:...\n");
     printf("            manually specify a host key (may be repeated)\n");
     printf("  -batch    disable all interactive prompts\n");
+    printf("  -proxycmd command\n");
+    printf("            use 'command' as local proxy\n");
     printf("  -sshlog file\n");
     printf("  -sshrawlog file\n");
     printf("            log protocol details to a file\n");
@@ -3015,8 +3023,10 @@ static void usage(void)
 
 static void version(void)
 {
-  printf("psftp: %s\n", ver);
-  cleanup_exit(1);
+  char *buildinfo_text = buildinfo("\n");
+  printf("psftp: %s\n%s\n", ver, buildinfo_text);
+  sfree(buildinfo_text);
+  exit(0);
 }
 
 /*
@@ -3197,6 +3207,11 @@ static int psftp_connect(char *userhost, char *user, int portnumber)
 
     back = &ssh_backend;
 
+    logctx = log_init(NULL, conf);
+    console_provide_logctx(logctx);
+
+    platform_psftp_pre_conn_setup();
+
     err = back->init(NULL, &backhandle, conf,
 		     conf_get_str(conf, CONF_host),
 		     conf_get_int(conf, CONF_port),
@@ -3206,9 +3221,7 @@ static int psftp_connect(char *userhost, char *user, int portnumber)
 	fzprintf(sftpError, "ssh_init: %s", err);
 	return 1;
     }
-    logctx = log_init(NULL, conf);
     back->provide_logctx(backhandle, logctx);
-    console_provide_logctx(logctx);
     while (!back->sendok(backhandle)) {
 	if (back->exitcode(backhandle) >= 0)
 	    return 1;
@@ -3441,8 +3454,6 @@ int psftp_main(int argc, char *argv[])
     argv += i;
     back = NULL;
 
-    platform_psftp_post_option_setup();
-
     /*
      * If the loaded session provides a hostname, and a hostname has not
      * otherwise been specified, pop it in `userhost' so that
